@@ -1,5 +1,6 @@
 ﻿from discontrol.Client import Client
 from discontrol.Message import Message
+from random import randint
 import time
 class DisFlood:
     def __init__(self,client : Client):
@@ -18,12 +19,14 @@ class DisFlood:
         self.CountMessagesForInterval = CountMessagesForInterval
     def Flood(self,Content : str,ReturnMessages : bool=False):
         Messages = []
+        md = 0
         for i in range(0,self.CountMessages):
             for ii in range(0,self.CountMessagesForInterval):
-                if len(Messages) > self.CountMessages - 1:
+                if md > self.CountMessages - 1:
                     return
-                Messages.append(self.Client.send_message(self.ChannelId,Content,ReturnMessages)) 
-            if len(Messages) > self.CountMessages - 1:
+                md+=1
+                Messages.append(self.Client.send_message(self.ChannelId,Content.replace("!rand!",f"{randint(0,10000)}"),ReturnMessages)) 
+            if md > self.CountMessages - 1:
                     return
             time.sleep(self.Interval)
         return Messages
